@@ -4,4 +4,4 @@ use Object::Simple;
 sub title  : Attr { default => 2 }
 sub author : Attr { default => 3 }
 
-Object::Simple->end;
+Object::Simple->build_class;
